==> qtjambi-webchannel-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWebChannel/QWebChannel_shell.h <==
#ifndef QWEBCHANNEL_SHELL_H
#define QWEBCHANNEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebChannel/qwebchannel.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWebChannel/qwebchannelabstracttransport.h>
#include <QtJambi/RegistryAPI>


class QWebChannel_shell : public QWebChannel, public QtJambiShellInterface
{
public:
    QWebChannel_shell(QObject* parent0 = nullptr);
    ~QWebChannel_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QWebChannel_mshell;
    friend class QWebChannel_oshell;
};


class QWebChannel_mshell : public QWebChannel_shell
{
public:
    using QWebChannel_shell::QWebChannel_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QWebChannel_oshell : public QWebChannel_mshell
{
public:
    using QWebChannel_mshell::QWebChannel_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebChannel_access : public QWebChannel
{
};

#endif // QWEBCHANNEL_SHELL_H

==> qtjambi-webchannel-debuginfo-linux-x64-6.6.3.jar: sources/QtJambiWebChannel/QWebChannel_shell.h <==
#ifndef QWEBCHANNEL_SHELL_H
#define QWEBCHANNEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebChannel/qwebchannel.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtWebChannel/qwebchannelabstracttransport.h>
#include <QtJambi/RegistryAPI>


class QWebChannel_shell : public QWebChannel, public QtJambiShellInterface
{
public:
    QWebChannel_shell(QObject* parent0 = nullptr);
    ~QWebChannel_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebChannel_access : public QWebChannel
{
};

#endif // QWEBCHANNEL_SHELL_H
